# Magenta Voice Skill SDK for Python

This folder contains the voice skill SDK for Python documentation.

* In the main folder you find documents that cover generic topics. The End-to-end Guide for Skill Development and Implementation section contains a complete guide on Magenta Voice Platform and the tools to configure skills for Magenta Smart Speakers.
* The `howtos` section contains more practical documents that explain how to solve common problems.
 

## Content

- [Introduction](intro.md)
- [Installation of the SDK](install.md)
- [File Structure of a Skill](skill_structure.md)
- [End-to-end Guide for Skill Development and Implementation Voice Platform](external_developers.md)
- [An overview to Telekom Voicification Suite](tvs.md)
- [Internationalization and Localization](i18n.md)
- [Skill Catalog for Hallo Magenta App](catalog.md)
- [Skill Configuration File](config.md)
- [Context](context.md)
- [Entities](entities.md)
- [Response](response.md)
- [Circuit Breakers and Tracing](tracing.md)
- [HTTP timeout exception](http_timeout_exception.md)
- [Kubernetes Integrations](k8s.md)
- [Use_Kits & Actions](use_kits_and_actions.md)
- [Deploy the Skill](running.md)
- [Serverless Deployment](serverless.md)

### How Tos

- [Simple Intent Examples](howtos/intent_example.md)
- [Create a Skill Skeleton](howtos/create_new_skill.md)
- [Cache Stuff](howtos/cache_stuff.md)
- [How to use Persistence Service](howtos/persistence_service.md)
- [Skill Manifest](howtos/skill_manifest.md)
- [Run Services locally in Docker Compose](howtos/local_services.md)
- [How to make HTTP Requests](howtos/make_http_requests.md)
- [Test a skill](howtos/testing.md)

### Articles

- [Working with Demo Skill](articles/demo_skill.md)
- [Creating a Custom Weather Skill](articles/weather_skill.md)

